<div class="breadcrumbs">
    {% for node in schema.nodes_from_root %}
        {% if loop.first %}
            Root
        {% else %}
            <a href="#{{ node.html_id }}"
               onclick="anchorLink('{{ node.html_id }}')">{{ node.name_for_breadcrumbs | upper_first }}</a>
        {% endif %}
        {% if not loop.last %}
            <i class="bi-arrow-right-short"></i>
        {% endif %}
    {% endfor %}
</div>