<?xml version="1.0" encoding="utf-8"?>
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
        xsi:schemaLocation="http://www.sitemaps.org/schemas/sitemap/0.9 https://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd">
    {% for page in pages %}
        <url>
            <loc>{{ page.out_path|string|replace('\\', '/')|full_url }}</loc>
            <priority>{{ page.meta['sort_priority'] / 100 }}</priority>
        </url>
    {% endfor %}
</urlset>
